Enum ilc::event::Time
[−]
[src]
pub enum Time {
Unknown,
Hms(u8, u8, u8),
Timestamp(i64),
}Different log formats carry different amounts of information. Some might hold enough information to calculate precise timestamps, others might only suffice for the time of day.
Variants
UnknownHms(u8, u8, u8)Timestamp(i64)